function L = legeval(x,n)
%LEGEVAL Evaluation of Legendre polynomials.
%   L = LEGEVAL(X,N) computes the values of the Legendre polynomials
%   up to order N in the points X.
%
%   The output L is (N+1)-by-numel(X) and contains the values of the
%   polynomials evaulated at the points in X.
%
%   See also LEGQUAD.

% S. Engblom 2010-008-24

% straightforward
x = reshape(x,1,[]);
j = [0.5 1:n]';
A = (2*j-1)./j*x;
B = (1-j)./j;
L = clenshaw(A,B);
