%EXPLOSION_REFINEDPLOT Plots and animations for EXPLOSION_REFINED.

% S. Engblom 2011-01-06

close all;

load data/explosion_refined
n = numel(sol);

tmax = zeros(1,n);
for i = 1:n
  tmax(i) = sol{i}.sol.x(end);
end

xx = linspace(-0.25,0.25);
j = [0.5 1:sol{1}.np-1]';
A = (2*j-1)./j*xx(:)';
B = (1-j)./j;
% (old version, slightly outside the interval where the solution remains
% physical:)
%tt = linspace(0,min(tmax),100);
%tt = tt([2 40 95 100]);
tt = [0.037 1.41 3.4 3.5717];
psi = zeros(size(xx,2),n);
iproblem = cell(1,n);
for j = 1:size(tt,2)
  for i = 1:n
    u = interp1(sol{i}.sol.x,sol{i}.sol.y',tt(j),'linear')';
    Dphi = sol{1}.cache.D1\(sol{1}.cache.D2*u(1:sol{1}.np,:));
    phi = clenshaw(A,B,u(1:sol{1}.np,:))';
    psi(:,i) = clenshaw(A,B,u(sol{1}.np+1:end,:))';
    Dphi = clenshaw(A,B,Dphi)';
    iproblem{i} = find(sol{1}.Pi <= sol{1}.Cn2*Dphi.^2.*psi(:,i)/2);
  end

  figure(j)
  plot(xx,psi(:,1),'r',xx,psi(:,2),'r--','LineWidth',1);
  hold on,
  for i = [1 2]
    xp = [min(xx(iproblem{i})) max(xx(iproblem{i}))];
    yp = 0.15/4*ones(size(xp));
    if ~isempty(xp)
      xp = xp([1 1 1 2 2 2]);
      yp = yp([1 1 1 2 2 2])+0.15*[1 -1 0 0 -1 1]/64;
    end
    plot(xp,yp,'k','LineWidth',2);
  end
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.05 0.10 0.15]);
  if mod(j,2) == 0
    set(gca,'yticklabel',[]);
  end
  if j < 3
    set(gca,'xticklabel',[]);
  end
  set(gcf,'PaperPositionMode','auto');
  set(gcf,'Position',[100 100 200 125]);
  
  figure(numel(tt)+j)
  plot(xx,psi(:,3),'b-.',xx,psi(:,4),'b--',xx,psi(:,5),'b','LineWidth',1);
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.05 0.10 0.15]);
  if mod(j,2) == 0
    set(gca,'yticklabel',[]);
  end
  if j < 3
    set(gca,'xticklabel',[]);
  end
  set(gcf,'PaperPositionMode','auto');
  set(gcf,'Position',[100 100 200 125]);
end

% save to file
fname = [cellstr(reshape(sprintf('unstable%d.eps',1:4),[],4)') ...
         cellstr(reshape(sprintf('stable%d.eps',1:4),[],4)')];
if exist('writeimages','var') && writeimages
  for j = 1:8
    figure(j),
    print('-depsc',['fig/' fname{j}]);
  end
  
  % fix bounding boxes (the hard way!)
  fid = fopen(['fig/' fname{3}]);
  while 1
    bb = fgetl(fid);
    if strncmp(bb,'%%BoundingBox:',14), break; end
  end
  pos = ftell(fid);
  fclose(fid);
  for j = [1 2 4]
    fid = fopen(['fig/' fname{j}],'r+');
    fseek(fid,pos-size(bb,2)-1,-1); % (the -1 is for the '\n')
    fprintf(fid,'%s',bb);
    fclose(fid);
  end

  fid = fopen(['fig/' fname{7}]);
  while 1
    bb = fgetl(fid);
    if strncmp(bb,'%%BoundingBox:',14), break; end
  end
  pos = ftell(fid);
  fclose(fid);
  for j = [5 6 8]
    fid = fopen(['fig/' fname{j}],'r+');
    fseek(fid,pos-size(bb,2)-1,-1); % (the -1 is for the '\n')
    fprintf(fid,'%s',bb);
    fclose(fid);
  end
end

% Energy plot

% build fine grid to evaluate psi in
xx = sol{1}.cache.xx;
xx = [xx ...                          % all quadrature points...
      0.5*(xx(1:end-1)+xx(2:end)) ... % ...plus in between...
      linspace(-1,1,1001)];           % ...and some more (including 0!)

psi = pdeeval(sol{1}.sol.y(sol{1}.np+1:end,:),xx);
minpsi = min(psi,[],1);
maxpsi = max(psi,[],1);
if any(maxpsi >= 1), error('psi >= 1 detected.'); end

E = energy(sol{1});
t = sol{1}.sol.x;

% remove non-physical values
iremove = find(minpsi <= 0);
E(iremove) = [];
t(iremove) = [];
% hence, for the numerical solution psi in this interval, 0 < psi < 1

E = E+0.4; % arbitrary shift in the y-direction
figure(9),
minE = min(E)-0.001;
maxE = max(E);
plot(t,E,'b', ...
     tt([1:4; 1:4]),[minE; maxE],'k:', ...
     tt,energy(sol{1},tt)+0.4,'ko','LineWidth',1);
axis([-0.08 1.04*t(end) minE maxE]);
xlabel('t'); ylabel('Energy');
set(gca,'xtick',0:0.5:3.5, ...
        'ytick',0:0.001:0.005,'yticklabel',[]);
set(gcf,'PaperPositionMode','auto');
set(gcf,'Position',[100 100 400 100]);
if exist('writeimages','var') && writeimages
  print('-depsc','fig/unstable_energy.eps');
end

return;

% movie of the explosion!
hfig5 = figure(10); clf,
hax = gca;
M = struct('cdata',{},'colormap',{});
xx = linspace(-0.25,0.25,sol{1}.np);
tt = linspace(0,min(tmax),200);
j = [0.5 1:sol{1}.np-1]';
A = (2*j-1)./j*xx(:)';
B = (1-j)./j;
psi = zeros(size(xx,2),n);
iproblem = cell(1,n);
for j = 1:size(tt,2)
  for i = 1:n
    u = interp1(sol{i}.sol.x,sol{i}.sol.y',tt(j),'linear')';
    phi = u(1:sol{1}.np,:);
    psi(:,i) = u(sol{1}.np+1:end,:)';
    Dphi = sol{1}.cache.D1\(sol{1}.cache.D2*phi);
    phi = clenshaw(A,B,phi)';
    psi(:,i) = clenshaw(A,B,psi(:,i))';
    Dphi = clenshaw(A,B,Dphi)';
    iproblem{i} = find(sol{1}.Pi <= sol{1}.Cn2*Dphi.^2.*psi(:,i)/2);
  end
  %title(sprintf('Time %e',tt(j)));

  subplot(1,2,1);
  plot(xx,psi(:,1),'r',xx,psi(:,2),'r--');
  hold on,
  for i = [1]
    plot(xx(iproblem{i}),0.15/4*ones(size(iproblem{i})),'k*');
  end
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.15]);
  drawnow; hold off

  subplot(1,2,2);
  plot(xx,psi(:,3),'b',xx,psi(:,4),'b--',xx,psi(:,5),'b-.');
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.15]);
  drawnow; hold off
  
  pause(0.01);
  M(j) = getframe(hfig5);
end
%movie2gif(M,{M(end).cdata},'fig/gif/explosion_refined.gif', ...
%          'delaytime',0.1,'loopcount',inf);

% again, but only case 1 & 2
hfig6 = figure(11), clf,
hax = gca;
M = struct('cdata',{},'colormap',{});

psi = zeros(size(xx,2),n);
iproblem = cell(1,n);
for j = 1:size(tt,2)
  for i = 1:n
    u = interp1(sol{i}.sol.x,sol{i}.sol.y',tt(j),'linear')';
    phi = u(1:sol{1}.np,:);
    psi(:,i) = u(sol{1}.np+1:end,:)';
    Dphi = sol{1}.cache.D1\(sol{1}.cache.D2*phi);
    phi = clenshaw(A,B,phi)';
    psi(:,i) = clenshaw(A,B,psi(:,i))';
    Dphi = clenshaw(A,B,Dphi)';
    iproblem{i} = find(sol{1}.Pi <= sol{1}.Cn2*Dphi.^2.*psi(:,i)/2);
  end
  %title(sprintf('Time %e',tt(j)));

  subplot(1,2,1);
  plot(xx,psi(:,1),'r');
  hold on,
  for i = [1]
    plot(xx(iproblem{i}),0.15/4*ones(size(iproblem{i})),'k*');
  end
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.15]);
  drawnow; hold off

  subplot(1,2,2);
  plot(xx,psi(:,2),'r');
  hold on,
  for i = [2]
    plot(xx(iproblem{i}),0.15/4*ones(size(iproblem{i})),'k*');
  end
  axis([xx([1 end]) 0 15e-2]);
  set(gca,'xtick',[-0.2 0 0.2],'ytick',[0 0.15]);
  drawnow; hold off
  
  pause(0.01);
  M(j) = getframe(hfig6);
end
%movie2gif(M,{M(end).cdata},'fig/gif/explosion_refined0.gif', ...
%          'delaytime',0.1,'loopcount',inf);
