%ISOTHERMPLOT

% S. Engblom 2011-01-01

% "unpack" and redraw graphics

% (1) parameters
Cn = 1/6;
Ex = 1;
psic = [0.0020 0.0056 0.016 0.035 0.075];
t = [0 100];

% (2) analytical prediction
psib = logspace(-3,0,100);
phib = 1; % *** detailed versions available
psi0a = tprod(psib,1./tsum(psib,psic,[3 2],[3 1]),[3 2],[1 2]);
figure(1); clf, h1 = gca;
loglog(h1,psib,psi0a,'b');
xlabel('\psi_b');
ylabel('\psi_0');
drawnow, hold on

% (3) numerical experiment
psib = logspace(-3,-1,7);
psi0a = tprod(psib,1./tsum(psib,psic,[3 2],[3 1]),[3 2],[1 2]);
psib = frepmat(psib,size(psic,2));
phib = ones(1,size(psib,2)); % *** detailed versions available
Pi = frepmat(-(1+1/Ex)/4./log(psic),size(psib,2)); % *** detailed versions available
psibn = zeros(size(Pi,2),size(psib,2));
psi0n = zeros(size(psibn));
isok = ones(size(sol));

for j = 1:size(sol,1)
  for i = 1:size(sol,2)
    sol{j,i}.cache = sol{1,1}.cache;
    
    x = linspace(0.95,1,50);
    x = [-x(end:-1:1) x];
    psi = sol{j,i}.sol.y(sol{j,i}.np+1:end,end);
    psibn(j,i) =  mean(pdeeval(psi,x));

    x = linspace(-Cn*1e-4,Cn*1e-4,7);
    psi = sol{j,i}.sol.y(sol{j,i}.np+1:end,end);
    psi0n(j,i) =  mean(pdeeval(psi,x));
    if sol{j,i}.sol.x(end) < t(end)
      isok(j,i) = 0;
    end
  end
end

m1 = plot(h1,psibn(isok == 1),psi0n(isok == 1),'ko');
m3 = plot(h1,psib(isok ~= 1),psi0a(isok ~= 1),'rx');
axis([0.5e-3 1e0 1e-2 1e0])

% suitable to talks:
%print -depsc fig/???.eps

% domain of instability according to simplified theory
if sol{1,1}.Fcase == 0
  psic = exp(linspace(log(0.004),log(0.2),15));
  x = -1./(2*log(psic))*(1+1/Ex); % = 2*Pi
  psib = psic.*x./(1-x);
  m2 = plot(psib,psib./(psib+psic),'r.-');
end

% suitable to talks:
%print -depsc fig/???.eps

% to a paper:
set(gcf,'PaperPositionMode','auto');
set(gcf,'Position',[100 100 400 250]);
set(m1,'MarkerSize',4);
if sol{1,1}.Fcase == 0
  set(m2,'MarkerSize',5);
end
plotname = sprintf('isotherm%d.eps',sol{1,1}.Fcase);
if exist('writeimages','var') && writeimages
  print('-depsc',['fig/' plotname]);
end
