% SURFMODEL_ALLPLOTS Generate plots to paper.

% S. Engblom 2012-09-14 (verification added)
% S. Engblom 2011-01-20

% This is a super-script calling several other scripts. Run from
% within /experiments; all results are saved to the local directories
% /fig and /data.
%
% WARNING: overwrites many files and takes a long time ~24hrs!

if ~exist('./fig','dir')
  mkdir fig % destination directory for images
end
if ~exist('./data','dir')
  mkdir data % destination directory for .mat-files
end

warning('off','pde:wBC'); % stay a bit silent...
warning('off','steady_state:wIncl');

fprintf('\n*** (1/5) stable/unstable cases ***\n\n');
explosion_refined     % overwrites data/explosion_refined.mat
clear all, close all
writeimages = 1;      % write images to files
explosion_refinedplot % overwrites fig/unstable[1-4].eps and
                      % fig/stable[1-4].eps
clear all, close all

fprintf('\n*** (2/5) adsorption isotherms ***\n\n');
expver = '';
isothermdriver % writes to data/isotherm_F[0-3].mat
clear all, close all
for Fcase = 0:3
  load(sprintf('data/isotherm_F%d',Fcase));
  writeimages = 1;
  isothermplot % overwrites fig/isotherm[0-3].eps
  clear all, close all
end

fprintf('\n*** (3/5) sample intial/final solutions ***\n\n');
expver = 0;
isothermdriver      % writes to data/isotherm_F[0-3]v0.mat
writeimages = 1;
isothermsamplesplot % overwrites fig/psisample[1-3].eps
clear all, close all

fprintf('\n*** (4/5) Ward-Tordai problem; adsorption dynamics ***\n\n');
expver = 1;
ward_tordaidriver      % writes to data/ward_tordai_F[2-3]v1.mat
close all
writeimages = 1;
ward_tordaisamplesplot % overwrites fig/ward_tordai_F3[1-6].eps
clear all, close all
for Fcase = 2:3
  load(sprintf('data/ward_tordai_F%dv%d',Fcase,1));
  writeimages = 1;
  ward_tordaiplot      % overwrites fig/ward_tordaifit10_F[2-3].eps and
  clear all, close all % fig/ward_tordaifitee_F[2-3].eps
end

clear all, close all
fprintf('\n*** (5/5) Verification ***\n\n');
verification; % writes to data/verification.mat
writeimages = 1;
verificationplot; % overwrites fig/verification.eps
clear all, close all

warning('on','pde:wBC'); % ...you can speak now!
warning('on','steady_state:wIncl');