%WARD_TORDAI Test of diffusion-controlled adsorption dynamics.

% S. Engblom 2011-01-07

% caution since we might be overwriting files
if ~exist('Fname','var')
  error('Missing meta-data. Consider using the driver.');
end

% parameters
Pe_phi = 1;
Pe_psi = 1;
Ex = 1;
psic = 0.016; % [0.0020 0.0056 0.016 0.035 0.075]
Pi = -(1+1/Ex)/4/log(psic);

% definition of width: 1-rho is the fraction of variation covered and
% this choice yields a width 2*Cn for the phase-field interface
rho = 1-tanh(1);
psi0 = psib./(psib+psic);
alpha = psib./((1-rho)*psib+rho*psi0);
dx = 2*Cn*atanh(sqrt(1+1/(2*Ex)-sqrt(1/(4*Ex^2)-4*Pi*log(alpha))));

% length scales, preferably with separation Cn << Lpsi << L = 2
Lpsi = dx.*psi0./psib;
scales = [frepmat(Cn,numel(Lpsi)) Lpsi' frepmat(2,numel(Lpsi))]
separation = scales(:,2:3)./scales(:,1:2)

%return;

sol = cell(size(psib));
for i = 1:size(psib,2)
  % initial data
  phifun = @(x)(tanh(x/Cn));
  psifun = @(x)(psib(i)*ones(size(x)));
  u0 = {phifun psifun};

  % solve
  figure(2), clf
  sol{i} = pde('w',[], ...
               'Pe_phi',Pe_phi, ...
               'Pe_psi',Pe_psi, ...
               'Cn',Cn, ...
               'Ex',Ex, ...
               'Pi',Pi, ...
               'Fcase',Fcase, ...
               'u0',u0, ...
               'np',500, ... % highly resolved
               'nq',750, ...
               'filter',0.25 ...
               );
  t = [0 10];
  normw = sqrt(diag(sol{i}.cache.Mass));
  normw = [normw; normw];
  sol{i}.sol = ode1s(@pderhs,t,sol{i}.u0, ...
                     {'rtol',1e-6./normw,'atol',1e-8, ...
                      'errnorm2',@(z)(norm(z,inf)), ...
                      'nlinauto',1, ...
                      'reportfun',@pdereport}, ...
                     sol{i});
end

if ~isempty(Fname)
  save(['data/' Fname],'sol','psib');
end
clear Fname % force caller/driver to make a new filename
