%WARD_TORDAIAUX

% S. Engblom 2011-02-16

% Auxiliary function for WARD_TORDAI. Used by both WARD_TORDAIPLOT and
% WARD_TORDAISAMPLESPLOT.

Cn = sol{1}.Cn;
Ex = sol{1}.Ex;
Pi = sol{1}.Pi;
Fcase = sol{1}.Fcase;
psic = exp(-1/4/Pi*(1+1/Ex));

% initial "target values" of psib and psi0eq
psib0 = psib;
psi0eq0 = psib0./(psib0+psic);
colors = {'b--' 'r--' 'g--' 'k--'};

% width
rho = 1-tanh(1);
alpha = psib0./((1-rho)*psib0+rho*psi0eq0);
dx = 2*Cn*atanh(sqrt(1+1/(2*Ex)-sqrt(1/(4*Ex^2)-4*Pi*log(alpha))));

% sampling points fpr the bulk, the sub-surface layer, and the interface
xb = linspace(-1,-1+Cn*1e-1,51);
xb = [xb -xb(end:-1:1)];
x1 = zeros(size(sol,2),size(xb,2));
for i = 1:size(sol,2)
  xx1 = linspace(-dx(i)/2*1.02,-dx(i)/2*0.98,51);
  x1(i,:) = [xx1 -xx1(end:-1:1)];
end
x0 = linspace(-Cn*1e-4,Cn*1e-4,7);

% final values of psib and psi0eq
psi0eq1 = zeros(size(sol));
for i = 1:size(sol,2)
  psi = sol{i}.sol.y(sol{i}.np+1:end,end);
  psib1(i) = mean(pdeeval(psi,xb));
  psi0eq1(i) = mean(pdeeval(psi,x0));
end

% first sort the temporal scales out
tlim = zeros(size(sol,2),7);
% [0 = tlim(i,1),tlim(i,2)] is the short initial (linear) transient
% (before the sub-surface region has reached its minimum value)
%
% [tlim(i,3),tlim(i,4)] is the diffusion t^(1/2) transient
% (after the sub-surface region have been depleated, but before the
% interface starts to become saturated)
%
% [tlim(i,5),tlim(i,6)] is the diffusion t^(-1/2) asymptotics
% (when the interface starts to be saturated but before boundary
% effects)
%
% tlim(i,7) is the time to drainage of the sub-surface region (saved
% for visual purposes).
for i = 1:size(sol,2)
  psi = sol{i}.sol.y(sol{i}.np+1:end,:);
  psi1 = mean(pdeeval(psi,x1(i,:))); % sub-surface layer
  % offset is usually 1, but in some cases one must skip a few values
  % in the beginning due to roundoff
  offset = find(diff(psi1) < -eps(1024*psib0(i)),1,'first');
  jmin = offset+find(diff(psi1(offset+1:end)) > 0,1,'first');  % minima of psi1
  psi_2 = 0.5*(psi1(1)+psi1(jmin));     % "50% there"
  psi_4 = 0.25*psi1(1)+0.75*psi1(jmin); % "recovered 25%"
  tlim(i,2) = sol{i}.sol.x(find(psi1(1:jmin) > psi_2,1,'last'));
  tlim(i,3) = sol{i}.sol.x(jmin+find(psi1(jmin+1:end) >=  psi_4,1,'first'));
  psi0 = mean(pdeeval(psi,x0));
  lims = [min(0.75*psi0eq1(i),20*psib0(i)) ...
          0.75*psi0eq1(i) ...
          0.75*psib0(i) ...
         ];
  for j = 1:2
    tlim(i,j+3) = sol{i}.sol.x(find(psi0 >= lims(j),1,'first'));
  end
  psiB = mean(pdeeval(psi,xb));
  tlim(i,6) = sol{i}.sol.x(find(psiB > lims(3),1,'last'));
  tlim(i,7) = sol{i}.sol.x(jmin);
end
if any(reshape(diff(tlim(:,1:6),[],2),[],1) < 0)
  warning('Empty temporal interval detected.');
end
