function M = mass(sol,t)
%MASS Evaluate mass.
%   M = MASS(SOL,T) evaluates the mass M of the solution in SOL at
%   times T. The output M is a 2-by-numel(T) matrix where M(:,i) is
%   the mass of the 2 variables at time T(i).
%
%   M = MASS(SOL) understands SOL as spectral coefficients
%   directly.
%
%   No error-checking is performed.
%
%   See also ENERGY.

% S. Engblom 2010-08-25

% straightforward
if isstruct(sol)
  if strcmp(sol.sol.solver,'ode1s')
    u = interp1(sol.sol.x,sol.sol.y',t,'linear')';
  else
    u = deval(sol.sol,t);
  end
else
  u = sol;
end

% using orthogonality...
M = 2*u([1 sol.np+1],:);
