function [phi,psi] = pdeeval(sol,x,t)
%PDEEVAL Evaluate solution to PDE.
%   [PHI,PSI] = PDEEVAL(SOL,X,T) evaluates the solution (PHI,PSI) to
%   the PDE in SOL at times T and coordinates X. Both outputs are
%   numel(X)-by-numel(T).
%
%   U = PDEEVAL(SOL,X) understands SOL as spectral coefficients of a
%   single solution directly.
%
%   See also PDEMOVIE.

% S. Engblom 2010-06-22

% straightforward
if isstruct(sol)
  if strcmp(sol.sol.solver,'ode1s')
    u = interp1(sol.sol.x,sol.sol.y',t,'linear')';
  else
    u = deval(sol.sol,t);
  end
  phi = u(1:sol.np,:);
  psi = u(sol.np+1:end,:);
  j = [0.5 1:sol.np-1]';
  A = (2*j-1)./j*x(:)';
  B = (1-j)./j;
  phi = clenshaw(A,B,phi)';
  psi = clenshaw(A,B,psi)';
else
  u = sol;
  j = [0.5 1:size(u,1)-1]';
  A = (2*j-1)./j*x(:)';
  B = (1-j)./j;
  phi = clenshaw(A,B,u)';
end

