function M = pdemovie(sol,x,t,psi0,phis,psis)
%PDEMOVIE Display movie of solution to PDE.
%   PDEMOVIE(SOL,X,T) displays a movie of the solution in SOL in the
%   domain defined by X and T. If either argument is missing or is
%   empty, X = quadrature points and T = all time-steps are
%   understood.
%
%   PDEMOVIE(SOL,X,T,PSI0) scales PSI by PSI0, where PSI0 = 1 is used
%   as default.
%
%   PDEMOVIE(...,PHIS,PSIS) uses PHIS(PSIS) as symbols when plotting
%   PHI(PSI). The default is PHIS = 'b', PSIS = 'r'.
%
%   M = PDEMOVIE(...) returns also the frames in a Matlab movie
%   struture, see GETFRAME.
%
%   See also PDEEVAL, PDEREPORT, GETFRAME, MOVIE2GIF.

% S. Engblom 2010-09-16

if nargin < 6 || isempty(psis)
  psis = 'r';
end
if nargin < 5 || isempty(phis)
  phis = 'b';
end
if nargin < 4 || isempty(psi0)
  psi0 = 1;
end
if nargin < 3 || isempty(t)
  t = sol.sol.x;
end
if nargin < 2 || isempty(x)
  x = sol.cache.xx;
end
if nargout > 0
  M = struct('cdata',{},'colormap',{});
end

[phi,psi] = pdeeval(sol,x,t);
ax = [min(x) max(x) ...
      max(-1,min(min(min(phi,[],2),min(psi,[],2)))) ...
      min(1,max(max(max(phi,[],2),max(psi,[],2))))];
for i = 1:size(t,2)
  plot(x,phi(:,i),phis,x,1/psi0*psi(:,i),psis);
  axis(ax);
  title(sprintf('Time t = %e',t(i)));
  drawnow;
  if nargout > 0
    M(i) = getframe;
  end
  pause(0.01);
end
